.. definitions.rst

.. various latex definitions.

.. math::

   \newcommand{\Game}[2]{\displaystyle\left\{ #1 \mid #2 \right\}}
   \newcommand{\leftoption}[1][G]{\mathcal{#1}^{L}}
   \newcommand{\rightoption}[1][G]{\mathcal{#1}^{R}}
